/*
 * American Sign Language Learning Aid (ASLLA),
 * Copyright (C) 2002
 *    andy_uehara@yahoo.com
 * 
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 675 Mass Ave, Cambridge, MA 02139, USA.
 * 
 */

#include "Csignwordcontainer.h"

CSignwordcontainer::CSignwordcontainer(){}

CSignwordcontainer::~CSignwordcontainer(){
  //remember to delete if mem is dynamic
  //surfcontainer delete's it's own memory
  Clear();
}

/////////////////////////////////////////////////////
////                    Friends
//////////////////////////////////////////////////////
//NOTE BOTH Friend classes don't call any surfcont. functions

ostream& operator << (ostream& os, const CSignwordcontainer& s){
  os<<s.Snwordcont.size()<<endl;
  for (unsigned int i=0;i<s.Snwordcont.size();i++)
    os<<*(s.Snwordcont[i]);
  return os;
}

istream& operator >> (istream& is, CSignwordcontainer& s){
  //cerr<<"istream& operator >> (istream& is, CSignwordcontainer& s)"<<endl;
  int val;
  CSignword* SignwordPtr;
  //clear all old data if there is any
  s.Clear();

  //read in new data
  is>>val;
  for (int i=0; i<val; i++){
    SignwordPtr=new CSignword;
    is>>*(SignwordPtr);
    s.Snwordcont.push_back(SignwordPtr);}
  return is;
}


void CSignwordcontainer::AddWord(CSignword* w){
  if (NULL==w)
    cerr<<"CSignwordcontainer::AddWord(CSignword* w) -w==NULL!!!"<<endl;
  else
    Snwordcont.push_back(w);
}

void CSignwordcontainer::Clear(){
  CSignword* SignwordPtr;
  if (Snwordcont.size() !=0){
    for (unsigned int i=0;i<Snwordcont.size();i++){
      SignwordPtr=Snwordcont[i];
      if (SignwordPtr != NULL)
	delete SignwordPtr;}
  }
  Snwordcont.clear();
}

void CSignwordcontainer::DumpFile (string s) const{
  ofstream DataFile (s.c_str(), ios::out);
  if (!DataFile){
    cerr<<"void CSignwordcontainer::DumpFile (string s)"<<endl;
    cerr<<" File"<<s<<" couldn't be opened!"<<endl;
  }
  else{
    DataFile<<*this;
  }
}

void CSignwordcontainer::Initialize (string CSwcconf){
  LoadFile(CSwcconf.c_str());
}

void CSignwordcontainer::LoadFile(string s){
  ifstream DataFile (s.c_str(), ios::in);
  if (!DataFile){
    cerr<<"void CSignwordcontainer::LoadFile(string s)"<<endl;
    cerr<<" File "<<s<<" couldn't be opened!"<<endl;}
  else{
    DataFile>>*this;}
}

void CSignwordcontainer::RemWord(string name){
  //uses delete!!! there might be an over count error
  //NOT TESTED !!!!
  //  cerr<<"CSignwordcontainer::RemWord(string name)"<<endl;
  Iter=Snwordcont.begin();
  for (unsigned int i=0;i<=Snwordcont.size();i++,Iter++){
    if ((Snwordcont[i])->GetName()==name){
      //      cerr<<" ERASING "<<name<<endl;
      SwordPtr=Snwordcont[i];
      delete SwordPtr;
      Snwordcont.erase(Iter);
    }
  }
}

void CSignwordcontainer::SetName(string s){
  Name=s;
}

int CSignwordcontainer::GetSize() const{
  return Snwordcont.size();
}

string CSignwordcontainer::GetName() const{
  return Name;
}

CSignword* CSignwordcontainer::FindWord(int num){
  //does a linear search for the name
  //if it doesn't find it returns the last word (blank)
  if (num<(int)Snwordcont.size())
    return Snwordcont[num];
  return NULL;
}

CSignword* CSignwordcontainer::FindWord(string name){
  //does a linear search for the name
  //if it doesn't find it returns the last word (blank)
  for (unsigned int i=0;i!=Snwordcont.size(); i++)
    if ((Snwordcont[i])->GetName()==name){
      SwordPtr=Snwordcont[i];
      return SwordPtr;}
  cerr<<"can't find word in database"<<endl;
  SwordPtr=Snwordcont[Snwordcont.size()-1];
  return SwordPtr;
}

void CSignwordcontainer::List(){
  //lists all the commands in it's memory as well as Surfcont functions
  cerr<<"LIST OF WORDS"<<endl;
  for (unsigned int i=0; i!=Snwordcont.size();i++){
    cerr<<setw(2)<<i<<" "<<setw(10)<<(Snwordcont[i])->GetName();
    cerr<<" "<<(Snwordcont[i])->GetFilename()<<endl;
  }
}










