/*
 * American Sign Language Learning Aid (ASLLA),
 * Copyright (C) 2002
 *    andy_uehara@yahoo.com
 * 
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 675 Mass Ave, Cambridge, MA 02139, USA.
 * 
 */

#include "Ctranslator.h"

CTranslator::CTranslator(){
  CswordcontPtr=NULL;
}

CTranslator::~CTranslator(){
  //remember to delete if mem is dynamic
  //surfcontainer delete's it's own memory
  Clear();
}

/////////////////////////////////////////////////////
////                    Friends
//////////////////////////////////////////////////////
//NOTE BOTH Friend classes don't call any surfcont. functions

ostream& operator << (ostream& os, const CTranslator& t){
  os<<t.Transvec.size()<<endl;
  for (unsigned int i=0;i<t.Transvec.size();i++)
    os<<(t.Transvec[i])->GetName();
  return os;
}

istream& operator >> (istream& is, CTranslator& t){
  //cerr<<"istream& operator >> (istream& is, CTranslator& t)"<<endl;
  int val;
  string data,input,swordcontconf,surfcontconf,tmp1;
  data="data/";
  swordcontconf="/swordcont.conf";
  surfcontconf="/surfcont.conf";
  CSignwordcontainer* CswordcontPtr;
  //clear all old data if there is any
  t.Clear();

  //read in new data
  is>>val;
  for (int i=0; i<val; i++){
    CswordcontPtr=new CSignwordcontainer;
    is>>input;
    tmp1=data+input+swordcontconf;
    CswordcontPtr->SetName(input);
    CswordcontPtr->Initialize(tmp1);
    tmp1=input="";
    t.Transvec.push_back(CswordcontPtr);}
  return is;
}


void CTranslator::AddSwordcont(CSignwordcontainer* w){
  if (NULL==w)
    cerr<<"CTranslator::AddSwordcont(CSignwordcontainer* w) -w==NULL!!!"<<endl;
  else
    Transvec.push_back(w);
}

void CTranslator::Clear(){
  CSignwordcontainer* CswordcontPtr;
  if (Transvec.size() !=0){
    for (unsigned int i=0;i<Transvec.size();i++){
      CswordcontPtr=Transvec[i];
      if (CswordcontPtr != NULL)
	delete CswordcontPtr;}
  }
  Transvec.clear();
}

void CTranslator::DumpFile (string s) const{
  ofstream DataFile (s.c_str(), ios::out);
  if (!DataFile){
    cerr<<"void CTranslator::DumpFile (string s)"<<endl;
    cerr<<" File"<<s<<" couldn't be opened!"<<endl;
  }
  else{
    DataFile<<*this;
  }
}

void CTranslator::Initialize (string Ctransconf){
  LoadFile(Ctransconf.c_str());
}

void CTranslator::LoadFile(string s){
  ifstream DataFile (s.c_str(), ios::in);
  if (!DataFile){
    cerr<<"void CTranslator::LoadFile(string s)"<<endl;
    cerr<<" File "<<s<<" couldn't be opened!"<<endl;}
  else{
    DataFile>>*this;}
}

void CTranslator::RemSwordcont(string name){
  //uses delete!!!
  //I think this over counts!! NOT TESTED!!!!
  //  cerr<<"CTranslator::RemSwordcont(string name)"<<endl;
  Iter=Transvec.begin();
  for (unsigned int i=0;i<=Transvec.size();i++,Iter++){
    if ((Transvec[i])->GetName()==name){
      //      cerr<<" ERASING "<<name<<endl;
      CswordcontPtr=Transvec[i];
      delete CswordcontPtr;
      Transvec.erase(Iter);
    }
  }
}

int CTranslator::GetSize() const{
  return Transvec.size();
}

CSignwordcontainer* CTranslator::GetSwordcont(){
  return CswordcontPtr;
}

CSignwordcontainer* CTranslator::FindSwordcont (int num){
  //Transvec starts from 0
  if (num<(int)Transvec.size())
    return Transvec[num];
  return NULL;
}
      
CSignwordcontainer* CTranslator::FindSwordcont(string name){
  //does a linear search for the name
  //if it doesn't find it returns the last word (blank)
  for (unsigned int i=0;i!=Transvec.size(); i++)
    if ((Transvec[i])->GetName()==name){
      CswordcontPtr=Transvec[i];
    return  CswordcontPtr;}
  cerr<<"can't find CSignwordcontainer in database"<<endl;
  CswordcontPtr=NULL;
  return  CswordcontPtr;
}

CSignword* CTranslator::FindWord(string s) {
  CSignword* tmp;
  if (NULL==CswordcontPtr){
    cerr<<"CSignword* CTranslator::FindWord(string s)";
    cerr<<" CswordcontPtr==NULL"<<endl;
    return NULL;}
  tmp=CswordcontPtr->FindWord(s);
  if (NULL==tmp)
    tmp=CswordcontPtr->FindWord("dne");
  return tmp;
}

void CTranslator::List(){
  //lists all the commands in it's memory as well as Surfcont functions
  cerr<<"LIST OF WORDS"<<endl;
  for (unsigned int i=0; i!=Transvec.size();i++)
    cerr<<setw(2)<<i<<" "<<setw(10)<<(Transvec[i])->GetName();
}









