/*
 * American Sign Language Learning Aid (ASLLA),
 * Copyright (C) 2002
 *    andy_uehara@yahoo.com
 * 
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 675 Mass Ave, Cambridge, MA 02139, USA.
 * 
 */
//PG
#include "paragui.h"
#include "pgpopupmenu.h"
#include "pgdropdown.h"
#include "pgrichedit.h"
#include "pgmenubar.h"
#include "pgspinnerbox.h"
//MY modified PG
#include "mywidget.h"
//REST of my
#include "Ctranslator.h" //grab the Csignwordcontainer class
#include "Cwordlist.h"
#include "Cmediator.h"

PARAGUI_CALLBACK(exit_handler) {
  PG_Application* app = (PG_Application*) clientdata;
  app->Quit();
  return true;
}

PARAGUI_CALLBACK(show_handler) {
  PG_LineEdit* wid = (PG_LineEdit*) clientdata;
  wid->Show();
  return true;
}

PARAGUI_CALLBACK(play_handler) {
  CMediator* wid = (CMediator*) clientdata;
  //cerr<<"PG_CALLBACK "<<wid->guessword<<endl;
  wid->PlayGuessWord();
  return true;
}

PARAGUI_CALLBACK(next_handler) {
  CMediator* wid = (CMediator*) clientdata;
  wid->ChangeRandomWord();
  return true;
}

PARAGUI_CALLBACK (spin_handler){
  CMediator* wid= (CMediator*) clientdata;
  wid->UpdateDelay();
  return true;
}

int main(int argc, char* argv[]) {
  CSignwordcontainer swcont;
  CWordlist wordl; 
  CMediator mediate;
  PG_Application app;

  //SET-UP GUI necessary to initialize my stuff
  app.LoadTheme("default");
  app.InitScreen(240, 320, 16, SDL_SWSURFACE);

  PG_LineEdit answer(NULL,PG_Rect(0,300,240,20),"LineEdit",25);
  answer.SetEditable(false);

  PG_Point pnt; pnt.x=0; pnt.y=80;
  MyWidget myWid (NULL,pnt,"data/asl/dne.jpg");
  myWid.Update();
  myWid.Show();

  PG_SpinnerBox mySpin(NULL, PG_Rect(195,160,80,30), "SpinnerBox");
  mySpin.SetMinValue(1); 
  mySpin.SetMaxValue (15);
  mySpin.SetValue(5);//same as in Mediator class
  mySpin.Show();

  //Initialize my stuff
  swcont.Initialize("data/asl-fingerspell/swordcont.conf");
  wordl.Initialize("data/aslla-fspell/american-english");
  mediate.SetWrdLst(&wordl);
  mediate.SetPGLineE(&answer);
  mediate.SetCSnWdCont(&swcont);
  mediate.SetMyWidget(&myWid);
  mediate.SetPGSpinner(&mySpin);
  mediate.ChangeRandomWord();

  //SETUP rest of GUI
  mySpin.SetEventCallback(MSG_SPINNER_CHANGE, spin_handler,&mediate);

  app.SetCaption("(ASLLA)-FINGERSPELLING",NULL);

  PG_Label myLabel(NULL,PG_Rect(0,0,240,20),"FINGERSPELL 101",NULL);
  myLabel.Show();
  PG_Label myLabel2(NULL,PG_Rect(110,160,60,30), "Speed");
  myLabel2.Show();
  PG_Button myButton(NULL,1, PG_Rect(180, 0, 60, 30), "Quit");
  myButton.SetEventCallback(MSG_BUTTONCLICK, exit_handler, &app);
  myButton.Show();
  PG_Button myButton2(NULL,2,PG_Rect(0, 190, 240, 30), "Show Hidden Word");
  myButton2.SetEventCallback(MSG_BUTTONCLICK, show_handler, &answer);
  myButton2.Show();
  PG_Button myButton3(NULL,3,PG_Rect(0,220,240,30), "Fingerspell Word");
  myButton3.SetEventCallback(MSG_BUTTONCLICK, play_handler, &mediate);
  myButton3.Show();
  PG_Button myButton4(NULL,4,PG_Rect(0,250,240,30), "Next Word");
  myButton4.SetEventCallback(MSG_BUTTONCLICK, next_handler, &mediate);
  myButton4.Show();

  app.Run();
  return 0;
}








